Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1406)

Unified Diff: Source/core/platform/image-decoders/gif/GIFImageReader.h

Issue 23464095: WTF::notFound looks too much like a local variable. (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 7 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/core/platform/image-decoders/gif/GIFImageReader.h
diff --git a/Source/core/platform/image-decoders/gif/GIFImageReader.h b/Source/core/platform/image-decoders/gif/GIFImageReader.h
index 33a1bd7a4396c2da6b298d386fb71ac49d9a5dbd..1197dd3e443f0469b9c1edc236435cc6b9f7e7c6 100644
--- a/Source/core/platform/image-decoders/gif/GIFImageReader.h
+++ b/Source/core/platform/image-decoders/gif/GIFImageReader.h
@@ -189,7 +189,7 @@ public:
, m_yOffset(0)
, m_width(0)
, m_height(0)
- , m_transparentPixel(notFound)
+ , m_transparentPixel(kNotFound)
, m_disposalMethod(WebCore::ImageFrame::DisposeNotSpecified)
, m_dataSize(0)
, m_progressiveDisplay(false)
@@ -258,7 +258,7 @@ private:
unsigned m_yOffset; // With respect to "screen" origin.
unsigned m_width;
unsigned m_height;
- size_t m_transparentPixel; // Index of transparent pixel. Value is notFound if there is no transparent pixel.
+ size_t m_transparentPixel; // Index of transparent pixel. Value is kNotFound if there is no transparent pixel.
WebCore::ImageFrame::DisposalMethod m_disposalMethod; // Restore to background, leave in place, etc.
int m_dataSize;

Powered by Google App Engine
This is Rietveld 408576698